@@ -652,3 +652,57 @@ class TestQueryBuilderSelectWithInclude(object):
             )
         )
         assert session.execute(query).scalar() == result
+
+    def test_hybrid_property_in_included_object(
+        self,
+        query_builder,
+        session,
+        category_cls,
+        comment_cls
+    ):
+        query = query_builder.select(
+            category_cls,
+            fields={'articles': ['comment_count']},
+            include=['articles'],
+            from_obj=session.query(category_cls).filter(
+                category_cls.id == 1
+            )
+        )
+        from pprint import pprint
+        pprint(session.execute(query).scalar())
+
+    @pytest.mark.parametrize(
+        ('fields', 'include', 'result'),
+        (
+            (
+                {
+                    'users': [],
+                },
+                [],
+                {
+                    'data': [{
+                        'type': 'users',
+                        'id': '5'
+                    }]
+                }
+            ),
+        )
+    )
+    def test_empty_list_as_included(
+        self,
+        query_builder,
+        session,
+        user_cls,
+        fields,
+        include,
+        result
+    ):
+        query = query_builder.select(
+            user_cls,
+            fields=fields,
+            include=include,
+            from_obj=session.query(user_cls).filter(
+                user_cls.id == 5
+            )
+        )
+        assert session.execute(query).scalar() == result
